[gparted] Use Gtk::Box for DialogPasswordEntry (!25)



commit cc6a085e60b18ab26787d7629ebaea51e95f42dd
Author: Luca Bacci <luca bacci982 gmail com>
Date:   Wed Feb 27 16:51:35 2019 +0100

    Use Gtk::Box for DialogPasswordEntry (!25)
    
    Gtk::HBox and Gtk::VBox were deprecated in Gtkmm 3.2.  Replace with
    plain Gtk::Box.
    
    This commit makes the change for DialogPasswordEntry.cc.
    
    Closes !25 - Modern Gtk3 - part 1

 src/DialogPasswordEntry.cc | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/DialogPasswordEntry.cc b/src/DialogPasswordEntry.cc
index c4bb9027..7e143679 100644
--- a/src/DialogPasswordEntry.cc
+++ b/src/DialogPasswordEntry.cc
@@ -35,8 +35,8 @@ DialogPasswordEntry::DialogPasswordEntry( const Partition & partition )
        /* TO TRANSLATORS: dialog title, looks like   LUKS Passphrase /dev/sda1 */
        this->set_title( Glib::ustring::compose( _("LUKS Passphrase %1"), partition.get_path() ) );
 
-       // Separate VBox to hold lines in the dialog.
-       Gtk::VBox *vbox( manage( new Gtk::VBox() ) );
+       // Separate vertical box to hold lines in the dialog.
+       Gtk::Box *vbox(manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL)));
        vbox->set_border_width( 5 );
        vbox->set_spacing( 5 );
        get_vbox()->pack_start( *vbox, Gtk::PACK_SHRINK );
@@ -47,8 +47,8 @@ DialogPasswordEntry::DialogPasswordEntry( const Partition & partition )
                        Gtk::PACK_SHRINK );
 
        // Line 2: "Passphrase: [              ]"
-       // (HBox holding prompt and entry box)
-       Gtk::HBox *entry_hbox( manage( new Gtk::HBox() ) );
+       // (Horizontal box holding prompt and entry box)
+       Gtk::Box *entry_hbox(manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)));
        entry_hbox->pack_start( *Utils::mk_label( "<b>"+ Glib::ustring( _("Passphrase:") ) + "</b>" ) );
        entry = manage( new Gtk::Entry() );
        entry->set_width_chars( 30 );


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]